@@ -10,8 +10,6 @@ from Supplychain.Protocol.objective_functions import DefaultObjectiveFunction, P
 
 from Supplychain.Generic.timer import Timer
 
-import json
-
 
 def get_optimization_objective(input_folder: str = "Input"):
     default_value = "ServiceLevelMaximization"
@@ -42,6 +40,7 @@ def run_cmaes_optimization(simulation_name: str,
         # Get data from the simulator
         df_decision_vars = simulator.decision_variables_df
         _end_cycle = simulator.GetModel().GetParameter('NumberOfCycle').GetAsInt()
+        _steps_per_cycle = simulator.GetModel().GetParameter('TimeStepPerCycle').GetAsInt()
 
         nb_pars = 0
 
@@ -78,7 +77,8 @@ def run_cmaes_optimization(simulation_name: str,
         # Initialization of the transformation which takes CMAES results and transform them on map: datapath -> value
         transformation = DefaultTransformation(df_decision_vars,
                                                machines,
-                                               _end_cycle)
+                                               _end_cycle,
+                                               _steps_per_cycle)
         t.split(time_prefix + "Prepare transformation")
 
         objective_function = DefaultObjectiveFunction()
