@@ -8,6 +8,22 @@ from Supplychain.Wrappers.environment_variables import EnvironmentVariables
 from Supplychain.Run.simulation import run_simple_simulation
 import comets as co
 
+default_parameters = {
+    "simulation_name": "Simulation",
+    "simulator_path": "Simulation",
+    "saving_results": False,
+    "local": False,
+    "amqp_consumer_adress": None,
+    "adx_writer": None,
+    "validation_folder": "Simulation/Output",
+    "parameter": "Transport Duration",
+    "variation": 0.5,
+    "change": "relative",
+    "timeinterval": False,
+    "initialtimestep": 0,
+    "finaltimestep": 0,
+}
+
 # parameter label: (entity_type, attribute_name, default)
 sensitive_parameters = {
     "Fixed Production Cost": (
@@ -151,19 +167,19 @@ map_to_default_attribute_name = {
 
 
 def local_sensitivity_analysis(
-    simulation_name: str,
-    amqp_consumer_adress: Union[str, None] = None,
-    parameter: str = "Transport Duration",  # type of variable on which the analysis is performed
-    adx_writer: Union[ADXAndFileWriter, None] = None,
-    variation: float = 0.5,  # variation value
-    change: str = "relative",  # change mode
-    local: bool = False,  # false to optionally send the results to adx ; true to return the results dataframe (useful for the test)
-    simulator_path: str = "Simulation",
-    saving_results: bool = False,
-    validation_folder: str = "Simulation/Output",  # Folder in which sensitivity analysis results are saved
-    timeinterval: bool = False,  # Whether the change happens during a specific interval (otherwise it is applied for the complete duration of the simulation)
-    initialtimestep: int = 0,  # Time step at which the modification starts to take place (included), only if timeinterval is true
-    finaltimestep: int = 0,  # Time step after which the modification ends (the modification still takes place at this time step), only if timeinterval is true
+    simulation_name: str = default_parameters["simulation_name"],
+    amqp_consumer_adress: Union[str, None] = default_parameters["amqp_consumer_adress"],
+    parameter: str = default_parameters["parameter"],  # type of variable on which the analysis is performed
+    adx_writer: Union[ADXAndFileWriter, None] = default_parameters["adx_writer"],
+    variation: float = default_parameters["variation"],  # variation value
+    change: str = default_parameters["change"],  # change mode
+    local: bool = default_parameters["local"],  # false to optionally send the results to adx ; true to return the results dataframe (useful for the test)
+    simulator_path: str = default_parameters["simulator_path"],
+    saving_results: bool = default_parameters["saving_results"],
+    validation_folder: str = default_parameters["validation_folder"],  # Folder in which sensitivity analysis results are saved
+    timeinterval: bool = default_parameters["timeinterval"],  # Whether the change happens during a specific interval (otherwise it is applied for the complete duration of the simulation)
+    initialtimestep: int = default_parameters["initialtimestep"],  # Time step at which the modification starts to take place (included), only if timeinterval is true
+    finaltimestep: int = default_parameters["finaltimestep"],  # Time step after which the modification ends (the modification still takes place at this time step), only if timeinterval is true
 ):
 
     with Timer("[Run Sensitivity]") as t:
@@ -240,19 +256,19 @@ def local_sensitivity_analysis(
 
 
 def run_one_sa(
-    simulation_name: str,
-    amqp_consumer_adress: Union[str, None] = None,
-    parameter: str = "Transport Duration",  # type of variable on which the analysis is performed
-    adx_writer: Union[ADXAndFileWriter, None] = None,
-    variation: float = 0.5,  # variation value
-    change: str = "relative",  # change mode
-    local: bool = False,  # false to optionally send the results to adx ; true to return the results dataframe (useful for the test)
-    simulator_path: str = "Simulation",
-    saving_results: bool = False,
-    validation_folder: str = "Simulation/Output",  # Folder in which sensitivity analysis results are saved
-    timeinterval: bool = False,  # Whether the change happens during a specific interval (otherwise it is applied for the complete duration of the simulation)
-    initialtimestep: int = 0,  # Time step at which the modification starts to take place (included), only if timeinterval is true
-    finaltimestep: int = 0,  # Time step after which the modification ends (the modification still takes place at this time step), only if timeinterval is true
+    simulation_name: str = default_parameters["simulation_name"],
+    amqp_consumer_adress: Union[str, None] = default_parameters["amqp_consumer_adress"],
+    parameter: str = default_parameters["parameter"],  # type of variable on which the analysis is performed
+    adx_writer: Union[ADXAndFileWriter, None] = default_parameters["adx_writer"],
+    variation: float = default_parameters["variation"],  # variation value
+    change: str = default_parameters["change"],  # change mode
+    local: bool = default_parameters["local"],  # false to optionally send the results to adx ; true to return the results dataframe (useful for the test)
+    simulator_path: str = default_parameters["simulator_path"],
+    saving_results: bool = default_parameters["saving_results"],
+    validation_folder: str = default_parameters["validation_folder"],  # Folder in which sensitivity analysis results are saved
+    timeinterval: bool = default_parameters["timeinterval"],  # Whether the change happens during a specific interval (otherwise it is applied for the complete duration of the simulation)
+    initialtimestep: int = default_parameters["initialtimestep"],  # Time step at which the modification starts to take place (included), only if timeinterval is true
+    finaltimestep: int = default_parameters["finaltimestep"],  # Time step after which the modification ends (the modification still takes place at this time step), only if timeinterval is true
 ):
 
     with Timer("[Run one sensitivity analysis]") as t:
@@ -295,6 +311,8 @@ def run_one_sa(
             error_message = f"Invalid parameter{'s' if len(errors) > 1 else ''}"
             raise ValueError(error_message)
 
+        t.split("{time_since_last_split:6.4f} ({time_since_start:6.4f}) - Variables creation and validation")
+
         def encoder(parameters):
             """
             Encoder of the task on which the S.A will be performed. The encoder receives a parameter set where
@@ -378,13 +396,14 @@ def run_one_sa(
             task=simulationtask, variables=list_of_variables, n_jobs=-2
         )
 
-        t.display_message("Starting simulations")
+        t.split("{time_since_last_split:6.4f} ({time_since_start:6.4f}) - Experiment initialization")
+
         experiment.run()
-        t.split("Ended simulations : {time_since_start}")
+
+        t.split("{time_since_last_split:6.4f} ({time_since_start:6.4f}) - Simulations")
 
         results = reformat_results(
             experiment.results,
-            simulation_name,
             change,
             variation,
             parameter,
@@ -393,6 +412,8 @@ def run_one_sa(
             finaltimestep,
         )
 
+        t.split("{time_since_last_split:6.4f} ({time_since_start:6.4f}) - Results reformatting")
+
     return results
 
 
@@ -466,11 +487,14 @@ def validate_absolute_variations(variables):
     for variable in variables:
         if variable["change"] == "absolute" and variable["variation"] < -variable["reference"]:
             entity_name = variable["name"].split('::{Entity}')[-1].split('::@')[0]
-            time_step = variable["name"].split('__@__')[-1]
+            time_step_message = ""
+            if "__@__" in variable["name"]:
+                time_step = variable["name"].split("__@__")[-1]
+                time_step_message = f" at time step {time_step}"
             errors.append(
                 f"Invalid variation value: {variable['variation']}."
                 f" With absolute change, it should be greater than or equal to {-variable['reference']}"
-                f" for entity {entity_name} at time step {time_step}."
+                f" for entity {entity_name}{time_step_message}."
             )
 
     return errors
@@ -504,9 +528,16 @@ def get_simulator_data(simulator_path, entity_type, attribute):
 
 
 def get_list_of_datapaths(cosmo_interface, entity_type, attribute):
+    entities = cosmo_interface.sim.GetModel().FindEntitiesByType(entity_type)
+    if entity_type == "Stock" and attribute != "PurchasingUnitCostSchedule":
+        entities = [
+            stock
+            for stock in entities
+            if not stock.GetAttribute("IsInfinite").Get()
+        ]
     suffixes = sorted(
         f"{{Entity}}{entity.GetName()}::@{attribute}"
-        for entity in cosmo_interface.sim.GetModel().FindEntitiesByType(entity_type)
+        for entity in entities
     )
 
     if not suffixes:
@@ -737,7 +768,6 @@ def get_type(value):
 
 def reformat_results(
     row_results,
-    simulation_name,
     change,
     variation,
     parameter,
@@ -770,7 +800,6 @@ def reformat_results(
         df = df[(df["TimeStep"] >= initialtimestep) & (df["TimeStep"] <= finaltimestep)]
 
     df["SimulationRun"] = EnvironmentVariables.simulation_id
-    df["ScenarioName"] = simulation_name
     df["Variable"] = str(parameter)
     df["Variation"] = float(variation)
     df["Change"] = str(change)
@@ -781,7 +810,7 @@ def reformat_results(
     df = df.rename(
         columns={
             "Output": "KPI",
-            "Name": "ID",
+            "Name": "id",
             "ReferenceOutputValue": "ReferenceKPI",
             "NewOutputValue": "NewKPI",
             "Difference": "Gap",
