@@ -4,9 +4,7 @@ import comets as co
 import numpy as np
 
 from Supplychain.Wrappers.simulator import CosmoEngine
-from Supplychain.Generic.adx_and_file_writer import ADXAndFileWriter
 from Supplychain.Generic.timer import Timer
-from Supplychain.Run.simulation import run_simple_simulation
 from Supplychain.Run.uncertainty_analysis_comets import UncertaintyAnalyzer
 from Supplychain.Wrappers.environment_variables import EnvironmentVariables
 
@@ -148,7 +146,7 @@ class StochasticOptimizer:
         # Create uncertainty analyzer
         consumers = ["Performances"]
         if self.KPI == "IndividualServiceLevelSatisfaction":
-            consumers.append("StocksFinal")
+            consumers.append("StocksAtEndOfSimulation")
 
         self.ua = UncertaintyAnalyzer(
             simulation_name=self.simulation_name,
@@ -429,11 +427,11 @@ def _compute_objective(
         else:
             objective = {"Objective": kpi, "KPI": kpi}
     else:
-        df_service = results["StocksFinal"][
-            results["StocksFinal"]["Indicator"] == "ServiceLevelSatisfaction"
+        df_service = results["StocksAtEndOfSimulation"][
+            results["StocksAtEndOfSimulation"]["Indicator"] == "ServiceLevelSatisfaction"
         ]
         if service_level_of_stocks != []:
-            df_service = df_service[df_service["StockId"].isin(service_level_of_stocks)]
+            df_service = df_service[df_service["id"].isin(service_level_of_stocks)]
         vector_of_service_levels = df_service[stat].to_numpy()
         if optimization_mode == "target":
             distance_to_target = (vector_of_service_levels - target_value) ** 2
