@@ -12,7 +12,7 @@ from Supplychain.Run.simulation import run_simple_simulation
 from Supplychain.Run.consumers import (
     StockConsumer,
     PerformanceConsumer,
-    StocksFinalConsumer,
+    StocksAtEndOfSimulationConsumer,
 )
 from Supplychain.Run.uncertainty_analysis_helper_functions import (
     get_max_time_step,
@@ -25,9 +25,7 @@ from Supplychain.Run.uncertainty_analysis_helper_functions import (
     collect_simulated_stock_final_output,
     collect_simulated_stock_output,
     collect_simulated_transport_output,
-    transform_transport_data,
-    transform_stock_data,
-    transform_stocksfinal_data,
+    transform_data,
     create_transport_distribution_sampling,
     create_demand_generator,
 )
@@ -44,7 +42,7 @@ class UncertaintyAnalyzer:
         sample_size (int): Number of simulations runs by the uncertainty analysis
         batch_size (int): Number of simulations runs that are run in a same batch by the uncertainty analysis
         amqp_consumer_adress (Union[str, None], optional): Adress of consumer to send probe results to. Defaults to None.
-        consumers (list, optional): Which consumers are activated. Defaults to ["Stocks", "Transport", "Performances", "StocksFinal", "PerformanceAMQP"].
+        consumers (list, optional): Which consumers are activated. Defaults to ["Stocks", "Transport", "Performances", "StocksAtEndOfSimulation", "PerformanceAMQP"].
         validation_folder (str, optional): Local folder to which results are written to, used by the tests. Defaults to None.
         cold_inputs (dict, optional): Parameters that are passed to the simulator at each simulation and don't change during the analysis. Defaults to {}.
         timer (Timer object, optional): Timer object that can be used for logs and counting time. Defaults to None.
@@ -57,7 +55,7 @@ class UncertaintyAnalyzer:
         sample_size,
         batch_size,
         amqp_consumer_adress=None,
-        consumers=["Stocks", "Transport", "Performances", "StocksFinal"],
+        consumers=["Stocks", "Transport", "Performances", "StocksAtEndOfSimulation"],
         validation_folder=None,
         cold_inputs={},
         timer=None,
@@ -88,7 +86,7 @@ class UncertaintyAnalyzer:
         """Setup and run the uncertainty analysis
 
         Returns:
-            dict: dictionary with keys among ["Stock", "Transport", "Performances", "StocksFinal"]
+            dict: dictionary with keys among ["Stock", "Transport", "Performances", "StocksAtEndOfSimulation"]
                 containing the output tables. Which table is available depends on the specified
                 consumers of the UncertaintyAnalyzer.
         """
@@ -125,10 +123,10 @@ class UncertaintyAnalyzer:
         if "Stocks" in self.consumers:
             used_probes.append("Stocks")
             custom_consumers.append((StockConsumer, "LocalConsumer", "Stocks"))
-        if "StocksFinal" in self.consumers:
-            used_probes.append("StocksFinal")
+        if "StocksAtEndOfSimulation" in self.consumers:
+            used_probes.append("StocksAtEndOfSimulation")
             custom_consumers.append(
-                (StocksFinalConsumer, "StocksFinalConsumer", "StocksFinal")
+                (StocksAtEndOfSimulationConsumer, "StocksAtEndOfSimulationConsumer", "StocksAtEndOfSimulation")
             )
         if "Performances" in self.consumers:
             used_probes.append("PerformanceIndicators")
@@ -310,7 +308,7 @@ class UncertaintyAnalyzer:
             The third parameter set contains the performance indicators {'3_OPEX': 0.0, '3_Profit': 1.0, ...}.
             The fourth parameter set looks like:
             {'4_A__&@&__TotalDemand': 1.0}.
-            The keys correspond to stock name + __&@&__ + category (TotalDemand, TotalServedQuantity, ServiceLevelSatisfaction)
+            The keys correspond to stock name + __&@&__ + category (TotalDemand, TotalServedQuantity, ServiceLevelSatisfaction, CycleServiceLevel)
             """
 
             output_parameterset = {}
@@ -338,12 +336,12 @@ class UncertaintyAnalyzer:
                         "3_", modelinterface.LocalPerformanceConsumer.memory[0]
                     )
                 )
-            if "StocksFinal" in consumers:
+            if "StocksAtEndOfSimulation" in consumers:
                 output_parameterset.update(
                     add_tag_to_parameterset(
                         "4_",
                         collect_simulated_stock_final_output(
-                            modelinterface.StocksFinalConsumer.memory
+                            modelinterface.StocksAtEndOfSimulationConsumer.memory
                         ),
                     )
                 )
@@ -425,7 +423,7 @@ class UncertaintyAnalyzer:
     def reformat_results(self):
         """Reformat results of the experiment so that they are compatible with the output tables"""
         self.results = {}
-        # Separating the results data on the different types of outputs (stock, transport, performances, stocksfinal)
+        # Separating the results data on the different types of outputs (stock, transport, performances, stocksatendofsimulation)
         self.experiment.results["statistics"].reset_index(inplace=True)
         self.experiment.results["statistics"]["OutputType"] = (
             self.experiment.results["statistics"]["index"]
@@ -442,14 +440,14 @@ class UncertaintyAnalyzer:
                 self.experiment.results["statistics"]["OutputType"] == "1"
             ]
             df_transport_duration = df_transport_duration.drop("OutputType", axis=1)
-            df_transport_final = transform_transport_data(df_transport_duration)
+            df_transport_final = transform_data(df_transport_duration)
             self.results["Transport"] = df_transport_final
         if "Stocks" in self.consumers:
             df_probe_data = self.experiment.results["statistics"][
                 self.experiment.results["statistics"]["OutputType"] == "2"
             ]
             df_probe_data = df_probe_data.drop("OutputType", axis=1)
-            df_stock_final = transform_stock_data(df_probe_data)
+            df_stock_final = transform_data(df_probe_data)
             self.results["Stock"] = df_stock_final
         if "Performances" in self.consumers:
             performances = self.experiment.results["statistics"][
@@ -458,13 +456,13 @@ class UncertaintyAnalyzer:
             performances = performances.drop("OutputType", axis=1)
             performances = performances.rename(columns={"index": "KPI"})
             self.results["Performances"] = performances
-        if "StocksFinal" in self.consumers:
-            df_stocksfinalconsumer = self.experiment.results["statistics"][
+        if "StocksAtEndOfSimulation" in self.consumers:
+            df_stocksatendofsimulationconsumer = self.experiment.results["statistics"][
                 self.experiment.results["statistics"]["OutputType"] == "4"
             ]
-            df_stocksfinalconsumer = df_stocksfinalconsumer.drop("OutputType", axis=1)
-            df_stocksfinalconsumer = transform_stocksfinal_data(df_stocksfinalconsumer)
-            self.results["StocksFinal"] = df_stocksfinalconsumer
+            df_stocksatendofsimulationconsumer = df_stocksatendofsimulationconsumer.drop("OutputType", axis=1)
+            df_stocksatendofsimulationconsumer = transform_data(df_stocksatendofsimulationconsumer, timestep=False)
+            self.results["StocksAtEndOfSimulation"] = df_stocksatendofsimulationconsumer
 
     def write_results_locally(self):
         """Write the results tables locally to csv files"""
@@ -493,8 +491,8 @@ class UncertaintyAnalyzer:
         self.results["Stock"].to_csv(
             str(self.validation_folder) + "/final_df_comets.csv", index=False
         )
-        self.results["StocksFinal"].to_csv(
-            str(self.validation_folder) + "/df_stocksfinal.csv", index=False
+        self.results["StocksAtEndOfSimulation"].to_csv(
+            str(self.validation_folder) + "/df_stocksatendofsimulation.csv", index=False
         )
         self.results["Transport"].to_csv(
             str(self.validation_folder) + "/df_transport.csv", index=False
@@ -526,7 +524,7 @@ def uncertainty_analysis(
             batch_size=batch_size,
             n_jobs=n_jobs,
             validation_folder=validation_folder,
-            consumers=["Transports", "Stocks", "StocksFinal", "Performances", "PerformanceAMQP"],
+            consumers=["Transports", "Stocks", "StocksAtEndOfSimulation", "Performances", "PerformanceAMQP"],
             cold_inputs=cold_inputs,
             timer=t,
         )
@@ -536,10 +534,10 @@ def uncertainty_analysis(
         if adx_writer is not None:
             t.split("Sending stats to ADX")
             adx_writer.write_target_file(
-                results["Stock"].to_dict("records"), "StockUncertaintiesStatistics"
+                results["Stock"].to_dict("records"), "StockUncertaintyStatistics"
             )
             adx_writer.write_target_file(
-                results["StocksFinal"].to_dict("records"), "StocksFinalUncertaintyStatistics"
+                results["StocksAtEndOfSimulation"].to_dict("records"), "StocksAtEndOfSimulationUncertaintyStatistics"
             )
             adx_writer.write_target_file(
                 results["Transport"].to_dict("records"),
