@@ -306,7 +306,7 @@ def collect_simulated_transport_output(transports_names, modelinterface, max_tim
         for value in transport_duration[
             f"Model::{{Entity}}IndustrialNetwork::{{Entity}}{transport}::@ActualDurationSchedule"
         ].values():
-            transport_duration_transformed[f"{transport}__&@&__{time_step}"] = value
+            transport_duration_transformed[f"{transport}__&@&__ActualDuration__&@&__{time_step}"] = value
             time_step += 1
     return transport_duration_transformed
 
@@ -361,21 +361,15 @@ def collect_simulated_stock_output(consumer_memory):
 
 def collect_simulated_stock_final_output(consumer):
     """
-    This function transforms the consumer memory to a list of
-    ParameterSets, where one ParameterSet is used for each stock.
+    This function transforms the consumer memory to a dictionary of
+    ParameterSets, where one ParameterSet is used for each stock-category.
     """
-    dic_of_parameterset = {}
-    for elements in consumer:
-        dic_of_parameterset[str(elements["ID"] + "__&@&__" + "TotalDemand")] = elements[
-            "TotalDemand"
-        ]
-        dic_of_parameterset[
-            str(elements["ID"] + "__&@&__" + "TotalServedQuantity")
-        ] = elements["TotalServedQuantity"]
-        dic_of_parameterset[
-            str(elements["ID"] + "__&@&__" + "ServiceLevelSatisfaction")
-        ] = elements["ServiceLevelSatisfaction"]
-    return dic_of_parameterset
+    categories = ("TotalDemand", "TotalServedQuantity", "ServiceLevelSatisfaction", "CycleServiceLevel")
+    return {
+        f"{elements['id']}__&@&__{category}": elements[category]
+        for elements in consumer
+        for category in categories
+    }
 
 
 """
@@ -478,137 +472,55 @@ def create_demand_generator(extended_demands, number_of_time_steps, DemandCorrel
 
 """
 -------------------------------------------------
-Functions that reformat the outputs of the uncertainty analysis
+Function that reformat the outputs of the uncertainty analysis
 -------------------------------------------------
 """
 
 
-def transform_stocksfinal_data(data):
+def transform_data(data, timestep=True):
     """
-    Transform output data by splitting the index column into a column of stock name, and a column with indicator name
+    Transform output data so that it matches the ADX table format
     """
-    restructured_df = data.copy()
-    restructured_df.loc[:, "SimulationRun"] = EnvironmentVariables.simulation_id
-    restructured_df[["StockId", "Category"]] = restructured_df["index"].str.split(
-        pat="__&@&__", expand=True
-    )
-    restructured_df = restructured_df[[
+    df = data.copy()
+    index_cols = [
+        "id",
+        "Category",
+        "TimeStep"
+    ]
+    if not timestep:
+        index_cols.remove("TimeStep")
+    if not df.empty:
+        df.loc[:, "SimulationRun"] = EnvironmentVariables.simulation_id
+        df[index_cols] = df["index"].str.split(pat="__&@&__", expand=True)
+    else:
+        index_cols.insert(0, "SimulationRun")
+        df[index_cols] = None
+    cols = [
         "SimulationRun",
-        "StockId",
+        "TimeStep",
+        "id",
         "Category",
-        "mean",
-        "sem",
         "quantile 5%",
         "quantile 25%",
         "quantile 50%",
         "quantile 75%",
         "quantile 95%",
-    ]]
-    restructured_df.rename(
-        columns={
-            "mean": "Mean",
-            "sem": "SE",
-            "quantile 5%": "Percentile5",
-            "quantile 25%": "Percentile25",
-            "quantile 50%": "Median",
-            "quantile 75%": "Percentile75",
-            "quantile 95%": "Percentile95",
-        },
-        inplace=True,
-    )
-    return restructured_df
-
-
-def transform_stock_data(data):
-    """
-    Transform output data so that it matches the ADX table format
-    """
-    # Splitting the first columns into 3 columns: TimeStep, StockId, Category
-    # And adding the simulationRun
-    temporary_df = data.copy()
-    temporary_df.loc[:, "SimulationRun"] = EnvironmentVariables.simulation_id
-    temporary_df[["StockId", "Category", "TimeStep"]] = temporary_df["index"].str.split(
-        pat="__&@&__", expand=True
-    )
-
-    # Removing unused columns such as index, quantile 10 ...
-    temporary_df = temporary_df.iloc[:, [1, 3, 5, 9, 14, 19, 23, 24, 25, 26, 27]]
-
-    # Changing the columns' order and renaming them to match the adx table
-    df_final = temporary_df[
-        [
-            "TimeStep",
-            "SimulationRun",
-            "StockId",
-            "quantile 5%",
-            "quantile 25%",
-            "quantile 50%",
-            "quantile 75%",
-            "quantile 95%",
-            "mean",
-            "sem",
-            "Category",
-        ]
+        "mean",
+        "sem",
     ]
-
-    df_final.rename(
+    if not timestep:
+        cols.remove("TimeStep")
+    df = df[cols]
+    df.rename(
         columns={
-            "quantile 5%": "Percentile5",
-            "quantile 25%": "Percentile25",
-            "quantile 50%": "Percentile50",
-            "quantile 75%": "Percentile75",
-            "quantile 95%": "Percentile95",
+            "quantile 5%": "FirstVigintile",
+            "quantile 25%": "FirstQuartile",
+            "quantile 50%": "Median",
+            "quantile 75%": "LastQuartile",
+            "quantile 95%": "LastVigintile",
             "mean": "Mean",
             "sem": "SE",
         },
         inplace=True,
     )
-    return df_final
-
-
-def transform_transport_data(data):
-    """
-    Transform output data so that it matches the ADX table format
-    """
-    # Adding the simulation run to the df
-    temporary_df = data.copy()
-    if not temporary_df.empty:
-        temporary_df.loc[:, "SimulationRun"] = EnvironmentVariables.simulation_id
-        # Splitting the first column into 2 columns: TransportOperation, TimeStep
-        temporary_df["TransportOperation"] = (
-            temporary_df["index"].str.split(pat="__&@&__", expand=False, n=1).str[0]
-        )
-        temporary_df["TimeStep"] = (
-            temporary_df["index"].str.split(pat="__&@&__", expand=False, n=1).str[1]
-        )
-    else:
-        temporary_df[["TransportOperation", "TimeStep"]] = None
-    df_final = temporary_df.iloc[:, 1:]
-
-    df_final.rename(
-        columns={
-            "confidence interval of the mean at 95%": "ConfidenceIntervalOfTheMeanAt95",
-            "quantile 5%": "Percentile5",
-            "quantile 10%": "Percentile10",
-            "quantile 15%": "Percentile15",
-            "quantile 20%": "Percentile20",
-            "quantile 25%": "Percentile25",
-            "quantile 30%": "Percentile30",
-            "quantile 35%": "Percentile35",
-            "quantile 40%": "Percentile40",
-            "quantile 45%": "Percentile45",
-            "quantile 50%": "Percentile50",
-            "quantile 55%": "Percentile55",
-            "quantile 60%": "Percentile60",
-            "quantile 65%": "Percentile65",
-            "quantile 70%": "Percentile70",
-            "quantile 75%": "Percentile75",
-            "quantile 80%": "Percentile80",
-            "quantile 85%": "Percentile85",
-            "quantile 90%": "Percentile90",
-            "quantile 95%": "Percentile95",
-        },
-        inplace=True,
-    )
-
-    return df_final
+    return df
