@@ -33,6 +33,8 @@ class ADTColumnDescription:
                 "Advance",
                 "Latitude",
                 "Longitude",
+                "IgnoreDownstreamRequiredQuantities",
+                "SourcingLimit",
             ],
             "change": [
                 "StorageUnitCosts",
@@ -54,6 +56,11 @@ class ADTColumnDescription:
                     "SalesForecasts",
                 ],
             },
+            "quantity": {
+                "PurchasingCosts": [
+                    "VariablePurchasingUnitCosts"
+                ],
+            },
         },
         "Transport": {
             "fixed": [
@@ -83,6 +90,7 @@ class ADTColumnDescription:
                     "InitialTransportedValues",
                 ]
             },
+            "quantity": {},
         },
         "Configuration": {
             "fixed": [
@@ -104,9 +112,26 @@ class ADTColumnDescription:
                 "ActualizeShipments",
                 "ActivateCorrelatedDemandUncertainties",
                 "DemandCorrelations",
+                "CarbonTax",
+                "Kpi",
+                "OptimizationMode",
+                "Statistic",
+                "TargetedValue",
+                "DecisionVariable",
+                "DecisionVariableMin",
+                "DecisionVariableMax",
+                "OptimizationMaximalDuration",
+                "OptimizationAlgorithm",
+                "OptimizationBatchSize",
+                "SampleSizeUncertaintyAnalysis",
+                "FinalSampleSizeUncertaintyAnalysis",
+                "MaxIterationsForOptim",
+                "AutomaticParallelizationConfig",
+                "MaxNumberOfSimInParallel",
             ],
             "change": [],
             "event": {},
+            "quantity": {},
         },
         "contains": {
             "fixed": [
@@ -115,6 +140,7 @@ class ADTColumnDescription:
             ],
             "change": [],
             "event": {},
+            "quantity": {},
         },
         "output": {
             "fixed": [
@@ -123,6 +149,7 @@ class ADTColumnDescription:
             ],
             "change": [],
             "event": {},
+            "quantity": {},
         },
         "input": {
             "fixed": [
@@ -132,6 +159,7 @@ class ADTColumnDescription:
             ],
             "change": [],
             "event": {},
+            "quantity": {},
         },
         "ProductionResource": {
             "fixed": [
@@ -146,8 +174,10 @@ class ADTColumnDescription:
             "change": [
                 "FixedProductionCosts",
                 "OpeningTimes",
+                "OpeningRates",
             ],
             "event": {},
+            "quantity": {},
         },
         "ProductionOperation": {
             "fixed": [
@@ -170,7 +200,9 @@ class ADTColumnDescription:
                 "MinimumOrderQuantities",
                 "MultipleOrderQuantities",
                 "SourcingProportions",
+                "ProductionProportions",
             ],
             "event": {},
+            "quantity": {},
         },
     }
