@@ -1,16 +1,17 @@
 parameters_default_values = {
     "Stock": {
-        #'id',
-        #'Label',
+        # "id",
+        # "Label",
         "PlantName": "",
         "Step": "",
         "PartId": "",
         "MinimalStock": -1,
         "MaximalStock": None,
-        #'InitialStock',
-        #'InitialValue',
-        #'IsInfinite',
+        # "InitialStock",
+        # "InitialValue",
+        # "IsInfinite",
         "PurchasingUnitCosts": {},
+        "VariablePurchasingUnitCosts": {},
         "CO2UnitEmissions": {},
         "UnitIncomes": {},
         "BacklogWeight": 1,
@@ -23,6 +24,8 @@ parameters_default_values = {
         "Advance": 0,
         "Latitude": 0.0,
         "Longitude": 0.0,
+        "IgnoreDownstreamRequiredQuantities": False,
+        "SourcingLimit": "Capacity",
         "StorageUnitCosts": {},
         "OrderPoints": {},
         "OrderQuantities": {},
@@ -34,10 +37,10 @@ parameters_default_values = {
         "SalesForecasts": {},
     },
     "Transport": {
-        #'Label',
-        #'source',
-        #'target',
-        #'Duration',
+        # "Label",
+        # "source",
+        # "target",
+        # "Duration",
         "Priority": 0,
         "Mode": "",
         "CustomFees": {},
@@ -46,7 +49,7 @@ parameters_default_values = {
         "ActualDurations": {},
         "MinimumOrderQuantities": {},
         "MultipleOrderQuantities": {},
-        #'SourcingProportions',
+        # "SourcingProportions",
         "TransportUncertaintiesParameter1": {},
         "TransportUncertaintiesParameter2": {},
         "TransportUncertaintiesParameter3": {},
@@ -64,7 +67,7 @@ parameters_default_values = {
         "ManageBacklogQuantities": False,
         "OptimizationObjective": "ServiceLevelMaximization",
         "SimulatedCycles": 1,
-        #'StartingDate',
+        # "StartingDate",
         "StepsPerCycle": 1,
         "TimeStepDuration": 1440,
         "UncertaintiesProbabilityDistribution": "Uniform",
@@ -73,34 +76,51 @@ parameters_default_values = {
         "ActualizeShipments": False,
         "ActivateCorrelatedDemandUncertainties": False,
         "DemandCorrelations": 0,
+        "CarbonTax": 0,
+        "Kpi": "Profit",
+        "OptimizationMode": "maximize",
+        "Statistic": "mean",
+        "TargetedValue": 80,
+        "DecisionVariable": "Order quantity",
+        "DecisionVariableMin": 0,
+        "DecisionVariableMax": 2000,
+        "OptimizationMaximalDuration": 3600,
+        "OptimizationAlgorithm": "NGOpt",
+        "OptimizationBatchSize": 1,
+        "SampleSizeUncertaintyAnalysis": 25,
+        "FinalSampleSizeUncertaintyAnalysis": 1000,
+        "MaxIterationsForOptim": 250,
+        "AutomaticParallelizationConfig": True,
+        "MaxNumberOfSimInParallel": 1,
     },
     "contains": {
-        #'source',
-        #'target',
+        # "source",
+        # "target",
     },
     "output": {
-        #'source',
-        #'target',
+        # "source",
+        # "target",
     },
     "input": {
-        #'source',
-        #'target',
+        # "source",
+        # "target",
         "InputQuantity": 1,
     },
     "ProductionResource": {
-        #'id',
-        #'Label',
+        # "id",
+        # "Label",
         "PlantName": "",
         "ProductionStep": "",
         "ProductionPolicy": "Equidistribution",
         "Latitude": 0.0,
         "Longitude": 0.0,
         "FixedProductionCosts": {},
-        #'OpeningTimes',
+        # "OpeningTimes",
+        "OpeningRates": {},
     },
     "ProductionOperation": {
-        #'id',
-        #'Label',
+        # "id",
+        # "Label",
         "PlantName": "",
         "IsContractor": False,
         "InvestmentCost": 0,
@@ -115,7 +135,8 @@ parameters_default_values = {
         "CO2UnitEmissions": {},
         "MinimumOrderQuantities": {},
         "MultipleOrderQuantities": {},
-        #'SourcingProportions',
+        # "SourcingProportions",
+        # "ProductionProportions",
     },
 }
 variables_default_values = {
@@ -130,6 +151,7 @@ variables_default_values = {
         "DemandWeights": 1,
         "SalesForecasts": 0,
         "PurchasingUnitCosts": 0,
+        "VariablePurchasingUnitCosts": 0,
         "CO2UnitEmissions": 0,
         "UnitIncomes": 0,
     },
@@ -137,11 +159,16 @@ variables_default_values = {
         "CustomFees": 0,
         "TransportUnitCosts": 0,
         "CO2UnitEmissions": 0,
-        #'ActualDurations': parameters_default_values['Transport']['Duration'],
+        "ActualDurations": 0,
         "MinimumOrderQuantities": 0,
         "MultipleOrderQuantities": 0,
+        "TransportUncertaintiesParameter1": 0,
+        "TransportUncertaintiesParameter2": 0,
+        "TransportUncertaintiesParameter3": 0,
+        "TransportUncertaintiesParameter4": 0,
         "InitialTransportedQuantities": 0,
         "InitialTransportedValues": 0,
+        "SourcingProportions": 1,
     },
     "Configuration": {},
     "contains": {},
@@ -149,6 +176,8 @@ variables_default_values = {
     "input": {},
     "ProductionResource": {
         "FixedProductionCosts": 0,
+        "OpeningTimes": 1440,
+        "OpeningRates": 1,
     },
     "ProductionOperation": {
         "QuantitiesToProduce": 0,
@@ -160,5 +189,7 @@ variables_default_values = {
         "CO2UnitEmissions": 0,
         "MinimumOrderQuantities": 0,
         "MultipleOrderQuantities": 0,
+        "SourcingProportions": 0,
+        "ProductionProportions": 0,
     },
 }
