@@ -236,6 +236,12 @@ class ValidationSchemas:
                     "if": {"minProperties": 1},
                     "then": {"required": ["0"]},
                 },
+                "ProductionProportions": {
+                    "type": "object",
+                    "patternProperties": {"^[0-9]+$": {"type": "number", "minimum": 0, "maximum": 1}},
+                    "if": {"minProperties": 1},
+                    "then": {"required": ["0"]},
+                },
                 "IsContractor": {"type": "boolean"},
                 "InvestmentCost": {
                     "type": "number",
@@ -256,11 +262,11 @@ class ValidationSchemas:
                 "ProductionPolicy": {
                     "type": "string",
                     "enum": [
-                        "None",
                         "Equidistribution",
                         "GreatestWorkload",
                         "SmallestWorkload",
                         "HighestPriority",
+                        "ProductionProportions",
                     ],
                 },
                 "OpeningTimes": {
@@ -269,6 +275,12 @@ class ValidationSchemas:
                     "if": {"minProperties": 1},
                     "then": {"required": ["0"]},
                 },
+                "OpeningRates": {
+                    "type": "object",
+                    "patternProperties": {"^[0-9]+$": {"type": "number", "minimum": 0, "maximum": 1}},
+                    "if": {"minProperties": 1},
+                    "then": {"required": ["0"]},
+                },
                 "FixedProductionCosts": {
                     "type": "object",
                     "patternProperties": {"^[0-9]+$": {"type": "number", "minimum": 0}},
@@ -311,6 +323,14 @@ class ValidationSchemas:
                     "if": {"minProperties": 1},
                     "then": {"required": ["0"]},
                 },
+                "VariablePurchasingUnitCosts": {
+                    "type": "object",
+                    "patternProperties": {
+                        "^[0-9]+$": {"type": "object", "patternProperties": {"^[0-9]+$": {"type": "number", "minimum": 0}}}
+                    },
+                    "if": {"minProperties": 1},
+                    "then": {"required": ["0"]},
+                },
                 "CO2UnitEmissions": {
                     "type": "object",
                     "patternProperties": {"^[0-9]+$": {"type": "number", "minimum": 0}},
@@ -402,6 +422,13 @@ class ValidationSchemas:
                 "Latitude": {"type": "number", "minimum": -90, "maximum": 90},
                 "Longitude": {"type": "number", "minimum": -180, "maximum": 180},
                 "IgnoreDownstreamRequiredQuantities": {"type": "boolean"},
+                "SourcingLimit": {
+                    "type": "string",
+                    "enum": [
+                        "Capacity",
+                        "CapacityQuantity",
+                    ],
+                },
             },
             "dependencies": {"InitialValue": ["InitialStock"]},
         },
