@@ -3,6 +3,7 @@ from typing import Union
 from CosmoTech_Acceleration_Library.Accelerators.adx_wrapper import ADXQueriesWrapper
 from Supplychain.Generic.adx_wrapper import ADXWrapper
 from Supplychain.Schema.adt_column_description import ADTColumnDescription
+from Supplychain.Schema.default_values import variables_default_values
 from Supplychain.Generic.timer import Timer
 from Supplychain.Generic.folder_io import FolderReader, FolderWriter
 
@@ -25,6 +26,9 @@ class FromDictToTableConverter(Timer, ADXAndFileWriter):
         for events in file_description['event'].values():
             time_elements.extend(events)
 
+        for quantity_descriptor in file_description['quantity'].values():
+            time_elements.extend(quantity_descriptor)
+
         for element in file_to_convert:
             _local_max = 0
             for time_element in time_elements:
@@ -58,10 +62,15 @@ class FromDictToTableConverter(Timer, ADXAndFileWriter):
         fixed_data = list()
         temporal_data = list()
 
-        events_filenames = list(file_description['event'].keys())
-        event_data = dict()
-        for _name in events_filenames:
-            event_data[_name] = list()
+        event_data = {
+            name: []
+            for name in file_description['event']
+        }
+
+        quantity_data = {
+            name: []
+            for name in file_description['quantity']
+        }
 
         for element in file_to_convert:
             # Each element will be converted separatly
@@ -69,6 +78,7 @@ class FromDictToTableConverter(Timer, ADXAndFileWriter):
             if self.simulation_id is not None:
                 current_fixed_data['SimulationRun'] = self.simulation_id
             current_events = dict()
+            current_quantity_data = {}
 
             # First fixed data are read
             for _key in file_description['fixed']:
@@ -94,33 +104,48 @@ class FromDictToTableConverter(Timer, ADXAndFileWriter):
                             schedule[str(_timestep)][change] = measure
                 return schedule
 
+            def read_quantity_data(columns: list) -> dict:
+                schedule = {}
+                for column in columns:
+                    values = element.get(column, {})
+                    if values:
+                        for t in sorted(values, key=int):
+                            for q in sorted(values[t], key=int):
+                                schedule.setdefault(str(t), {}).setdefault(str(q), {})[column] = values[t][q]
+                return schedule
+
             # We read the temporal data for "changes" and "events"
             current_changes = read_data(file_description['change'])
-            for event_name, event_columns in file_description['event'].items():
-                current_events[event_name] = read_data(event_columns)
+            for name, columns in file_description['event'].items():
+                current_events[name] = read_data(columns)
+            for name, columns in file_description['quantity'].items():
+                current_quantity_data[name] = read_quantity_data(columns)
 
             fixed_data.append(current_fixed_data)
 
             # We prepare a data structure to keep the latest change value for our data
             current_change_value = dict()
             for k in file_description['change']:
-                # Needs a default value depending on the key
-                current_change_value[k] = 0
+                current_change_value[k] = variables_default_values[file_name][k]
+            current_quantity_value = dict()
+            for k in file_description['change']:
+                current_change_value[k] = variables_default_values[file_name][k]
 
             # We create a base row which will be duplicated and filed for each timestep
             present_base = [_k for _k in base_row_keys if _k in current_fixed_data]
             base_row = {_k: current_fixed_data[_k] for _k in present_base}
             previous_row = None
-            for timestep in range(self.total_time_step):
+            for t in range(self.total_time_step):
+                timestep = str(t)
                 if file_description['change']:
                     current_row = base_row.copy()
-                    current_row['Timestep'] = str(timestep)
+                    current_row['Timestep'] = timestep
 
                     def change_from_key(local_key):
                         # In case of a change if the value exists in the data at a given time step
                         # we update our current value then set it in the row
-                        if str(timestep) in current_changes and local_key in current_changes[str(timestep)]:
-                            current_change_value[local_key] = current_changes[str(timestep)][local_key]
+                        if timestep in current_changes and local_key in current_changes[timestep]:
+                            current_change_value[local_key] = current_changes[timestep][local_key]
                         current_row[local_key] = current_change_value[local_key]
 
                     # We loop over all our keys in "changes" and in "events"
@@ -142,19 +167,35 @@ class FromDictToTableConverter(Timer, ADXAndFileWriter):
 
                 for event_name, event_columns in file_description['event'].items():
                     event_row = base_row.copy()
-                    event_row['Timestep'] = str(timestep)
+                    event_row['Timestep'] = timestep
                     event_exists = False
                     current_event = current_events[event_name]
                     for event_key in event_columns:
-                        if str(timestep) in current_event and event_key in current_event[str(timestep)]:
-                            event_row[event_key] = current_event[str(timestep)][event_key]
+                        if timestep in current_event and event_key in current_event[timestep]:
+                            event_row[event_key] = current_event[timestep][event_key]
                             event_exists = True
                         else:
-                            # Needs a default value depending on the key
-                            event_row[event_key] = 0.0
+                            event_row[event_key] = variables_default_values[file_name][event_key]
                     if event_exists or self.keep_duplicate:
                         event_data[event_name].append(event_row)
 
+                for name, columns in file_description['quantity'].items():
+                    datum = current_quantity_data[name]
+                    if timestep in datum:
+                        for quantity, values in datum[timestep].items():
+                            row = base_row.copy()
+                            row['Timestep'] = timestep
+                            row['Quantity'] = quantity
+                            value_is_defined = False
+                            for column in columns:
+                                if column in values:
+                                    row[column] = values[column]
+                                    value_is_defined = True
+                                else:
+                                    row[column] = variables_default_values[file_name][column]
+                            if value_is_defined or self.keep_duplicate:
+                                quantity_data[name].append(row)
+
         if fixed_data:
             self.write_target_file(fixed_data, fixed_data_filename, self.simulation_id)
         else:
@@ -190,7 +231,19 @@ class FromDictToTableConverter(Timer, ADXAndFileWriter):
                 if self.simulation_id:
                     fake_event_element['SimulationRun'] = self.simulation_id
                 self.write_target_file([fake_event_element, ], event_name, self.simulation_id)
-        self.split("{time_since_last_split:6.4f}({time_since_start:6.4f}) - " + file_name)
+        for name, file_content in quantity_data.items():
+            if file_content:
+                self.write_target_file(file_content, name, self.simulation_id)
+            elif file_description['quantity'][name]:
+                fake_content = {
+                    column: None
+                    for columns in (fake_row_keys, ['Timestep', 'Quantity'], file_description['quantity'][name])
+                    for column in columns
+                }
+                if self.simulation_id:
+                    fake_content['SimulationRun'] = self.simulation_id
+                self.write_target_file([fake_content, ], name, self.simulation_id)
+        self.split("{time_since_last_split:6.4f} ({time_since_start:6.4f}) - " + file_name)
 
     def __init__(self,
                  simulation_id: Union[str, None],
