@@ -213,6 +213,9 @@ class DictValidator(Timer):
         self.__sourcing_proportions_check()
         self.split("\tsourcing_proportions_check: {time_since_last_split:6.4f}s")
 
+        self.__production_proportions_check()
+        self.split("\tproduction_proportions_check: {time_since_last_split:6.4f}s")
+
         self.__check_resource_dependencies()
         self.split("\tcheck_resource_dependencies: {time_since_last_split:6.4f}s")
 
@@ -382,6 +385,38 @@ class DictValidator(Timer):
                                         'SourcingProportions',
                                         f"The sum of the {stock} sources proportions ({', '.join(sources)}) is not equal to one for the time step{'s' if len(errors) > 1 else ''}: {', '.join(errors)}"))
 
+    def __production_proportions_check(self):
+        operations_by_resource = {}
+        production_proportions = {}
+
+        for contains in self.reader.files.get('contains', []):
+            operations_by_resource.setdefault(contains['source'], []).append(contains['target'])
+        for operation in self.reader.files.get('ProductionOperation', []):
+            production_proportions[operation['id']] = operation.get('ProductionProportions')
+
+        e = 1e-2
+        for resource, operations in operations_by_resource.items():
+            considered_operations = {operation for operation in operations if production_proportions[operation] is not None}
+            if considered_operations:
+                time_steps = sorted(set(
+                    t
+                    for operation in considered_operations
+                    for t in production_proportions[operation]
+                ), key=int)
+                proportions = {}
+                errors = []
+                for time_step in time_steps:
+                    for operation in considered_operations:
+                        if time_step in production_proportions[operation]:
+                            proportions[operation] = production_proportions[operation][time_step]
+                    proportions_sum = sum(proportions.values())
+                    if proportions_sum < 1 - e or proportions_sum > 1 + e:
+                        errors.append(time_step)
+                if errors:
+                    self.errors.append(('ProductionOperationSchedules',
+                                        'ProductionProportions',
+                                        f"The sum of the {resource} operations proportions ({', '.join(operations)}) is not equal to one for the time step{'s' if len(errors) > 1 else ''}: {', '.join(errors)}"))
+
     def find_relations_by_id(self, relation_name: str, looked_id: str, relation_column: str):
         if (relation_name, looked_id, relation_column) not in self.lookup_memory:
             self.lookup_memory[(relation_name, looked_id, relation_column)] = [
