@@ -2,13 +2,14 @@
 # -*- coding:utf-8 -*-
 import os
 from collections import namedtuple
-# environ change to avoid a crash on multiple simulations: PROD-5387
-os.environ['CSM_METRICS_MODE'] = "off"
 
 import pandas
 
 import csm.engine as CosmoEngine
 
+# environ change to avoid a crash on multiple simulations: PROD-5387
+os.environ['CSM_METRICS_MODE'] = "off"
+
 
 def register_into_simulatorinterface(method):
     if hasattr(method, "fget"):
@@ -88,7 +89,7 @@ def _decision_variables(self):
                     "Machine",
                     name,
                     op_name,
-                    "StockTypeProportions",
+                    "ProductionProportionSchedule",
                     groups.GetAttribute(k).GetAttributeAsString("StartCycle"),
                     groups.GetAttribute(k).GetAttributeAsString("EndCycle"),
                     k
@@ -451,3 +452,28 @@ def get_demands(self, force=False):
                 demand.GetAttribute("BacklogWeight").Get(),
                 demand.GetAttribute("WeightMax").Get(),
             )
+
+
+@register_into_simulatorinterface
+def uses_variable_purchasing_costs(self, force=False):
+    return any(
+        stock.GetAttribute("VariablePurchasingUnitCostSchedule").Get()
+        for stock in self.get_entities_by_type('Stock', force=force)
+    )
+
+
+@register_into_simulatorinterface
+def get_variable_purchasing_costs_by_stock(self, force=False):
+    purchasing_costs_by_stock = {}
+    for stock in self.get_entities_by_type('Stock', force=force):
+        purchasing_unit_cost = stock.GetAttribute("PurchasingUnitCost").Get()
+        purchasing_unit_costs = stock.GetAttribute("PurchasingUnitCostSchedule").Get()
+        variable_purchasing_unit_costs = stock.GetAttribute("VariablePurchasingUnitCostSchedule").Get()
+        if variable_purchasing_unit_costs:
+            for t, variable_purchasing_unit_cost in variable_purchasing_unit_costs.items():
+                if 0 not in variable_purchasing_unit_cost.keys():
+                    if purchasing_unit_costs:
+                        purchasing_unit_cost = purchasing_unit_costs[max(u for u in purchasing_unit_costs.keys() if u <= t)]
+                    variable_purchasing_unit_cost[0] = purchasing_unit_cost
+            purchasing_costs_by_stock[stock.GetName()] = variable_purchasing_unit_costs
+    return purchasing_costs_by_stock
